package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.ApmApplicationPerformanceManagementServices;

/**
 * APM应用性能管理服务Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface ApmApplicationPerformanceManagementServicesMapper 
{
    /**
     * 查询APM应用性能管理服务
     * 
     * @param id APM应用性能管理服务主键
     * @return APM应用性能管理服务
     */
    public ApmApplicationPerformanceManagementServices selectApmApplicationPerformanceManagementServicesById(Integer id);

    /**
     * 查询APM应用性能管理服务列表
     * 
     * @param apmApplicationPerformanceManagementServices APM应用性能管理服务
     * @return APM应用性能管理服务集合
     */
    public List<ApmApplicationPerformanceManagementServices> selectApmApplicationPerformanceManagementServicesList(ApmApplicationPerformanceManagementServices apmApplicationPerformanceManagementServices);

    /**
     * 新增APM应用性能管理服务
     * 
     * @param apmApplicationPerformanceManagementServices APM应用性能管理服务
     * @return 结果
     */
    public int insertApmApplicationPerformanceManagementServices(ApmApplicationPerformanceManagementServices apmApplicationPerformanceManagementServices);

    /**
     * 修改APM应用性能管理服务
     * 
     * @param apmApplicationPerformanceManagementServices APM应用性能管理服务
     * @return 结果
     */
    public int updateApmApplicationPerformanceManagementServices(ApmApplicationPerformanceManagementServices apmApplicationPerformanceManagementServices);

    /**
     * 删除APM应用性能管理服务
     * 
     * @param id APM应用性能管理服务主键
     * @return 结果
     */
    public int deleteApmApplicationPerformanceManagementServicesById(Integer id);

    /**
     * 批量删除APM应用性能管理服务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteApmApplicationPerformanceManagementServicesByIds(Integer[] ids);
}
